==> blanco.plugin.dbphp_0.0.9-src.zip: blancoDbPhpPlugin/src/blanco/plugin/dbphp/wizards/BlancoDbPhpWizardPage99.java <==
/*
 * blancoDb Enterprise Edition
 * Copyright (C) 2004-2005 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.dbphp.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.plugin.dbphp.BlancoDbPhpPluginConstants;

public class BlancoDbPhpWizardPage99 extends AbstractBlancoDbPhpWizardPage99 {

    public BlancoDbPhpWizardPage99(ISelection selection) {
        super(selection);
        setTitle("blancoDbDotNetvOCpxEBU[h̊");
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE)
                .setText("blancoDbDotNetvOCpxEBU[h Ŋ܂B");
        new Label(container, SWT.NONE)
                .setText("  1.EBU[h ublancoDbDotNet ݒt@C GfB^v\܂B");
        new Label(container, SWT.NONE).setText("    ̉ʂ "
                + BlancoDbPhpPluginConstants.TARGET_FILENAME
                + "t@C̃GfB^vOɑ܂B");
        new Label(container, SWT.NONE).setText("  2.ʕ\ɏ]đi߂ĂB");

        setControl(container);
    }
}

==> blanco.plugin.dbphp_0.1.2-src.zip: blancoDbPhpPlugin/src/blanco/plugin/dbphp/wizards/BlancoDbPhpWizardPage99.java <==
/*
 * blancoDb Enterprise Edition
 * Copyright (C) 2004-2005 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.dbphp.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.plugin.dbphp.BlancoDbPhpPluginConstants;

public class BlancoDbPhpWizardPage99 extends AbstractBlancoDbPhpWizardPage99 {

    public BlancoDbPhpWizardPage99(ISelection selection) {
        super(selection);
        setTitle("blancoDbPhp vOCpxEBU[h̊");
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE)
                .setText("blancoDbPhp vOCpxEBU[h Ŋ܂B");
        new Label(container, SWT.NONE)
                .setText("  1.EBU[h ublancoDbPhp ݒt@C GfB^v\܂B");
        new Label(container, SWT.NONE).setText("    ̉ʂ "
                + BlancoDbPhpPluginConstants.TARGET_FILENAME
                + "t@C̃GfB^vOɑ܂B");
        new Label(container, SWT.NONE).setText("  2.ʕ\ɏ]đi߂ĂB");

        setControl(container);
    }
}
